package du2;

import du1.Byt;
import du1.Dum;
import du1.IRealitniKancelar;
import du1.Nemovitost;
import du1.Pozemek;
import du1.Vlastnictvi;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.JTextField;

/**
 *
 * @author Ing. Jaroslav Kuchař <kuchajar at fel.cvut.cz>
 */
public class Dialog extends JDialog {

    private Nemovitost nemovitost;
    private JTextField nazev, cena, plocha, adresa, cenaZaM2, pokoje;
    private JComboBox vlastnictvi;
    private JButton akce;
    private IRealitniKancelar realitka;
    private JTable table;

    private enum TypAkce {

        SMAZAT, NOVY
    };
    private TypAkce typ;

    public Dialog(IRealitniKancelar realitka, int i, JTable table) {
        super(new JFrame(), "Nemovitost", true);
        this.nemovitost = realitka.vrat(i);
        this.realitka = realitka;
        this.table = table;
        this.typ = TypAkce.SMAZAT;
        initGui();
        if (nemovitost != null) {
            nacti();
        }

        nazev.setEditable(false);
        cena.setEditable(false);
        plocha.setEditable(false);
        adresa.setEditable(false);
        cenaZaM2.setEditable(false);
        pokoje.setEditable(false);
        vlastnictvi.setEditable(false);
        if (nemovitost.isProdano() || nemovitost.isRezervovano()) {
            akce.setEnabled(false);
        }
    }

    public Dialog(IRealitniKancelar realitka, Nemovitost nemovitost, JTable table) {
        super(new JFrame(), "Nemovitost", true);
        this.nemovitost = nemovitost;
        this.realitka = realitka;
        this.table = table;
        this.typ = TypAkce.NOVY;
        initGui();
        if (nemovitost != null) {
            nacti();
        }
    }

    private void nacti() {
        nazev.setText(nemovitost.getNazev());
        cena.setText(String.valueOf(nemovitost.getCena()));
        plocha.setText(String.valueOf(nemovitost.getPlocha()));
        adresa.setText(nemovitost.getAdresa());
        vlastnictvi.setSelectedIndex(nemovitost.getVlastnictvi().ordinal());
        pokoje.setEnabled(false);
        cenaZaM2.setEnabled(false);
        if (nemovitost instanceof Byt) {
            Byt b = (Byt) nemovitost;
            pokoje.setText(String.valueOf(b.getPocetMistnosti()));
            pokoje.setEditable(true);
        }
        if (nemovitost instanceof Pozemek) {
            Pozemek p = (Pozemek) nemovitost;
            cenaZaM2.setText(String.valueOf(p.getCenaZaM2()));
            cenaZaM2.setEnabled(true);
        }
        if (nemovitost instanceof Dum) {
            Dum d = (Dum) nemovitost;
            pokoje.setText(String.valueOf(d.getPocetMistnosti()));
            pokoje.setEnabled(true);
            cenaZaM2.setText(String.valueOf(d.getCenaZaM2()));
            cenaZaM2.setEnabled(true);
        }

    }

    private void initGui() {
        this.setLayout(new GridLayout(8, 2));
        nazev = new JTextField();
        cena = new JTextField();
        plocha = new JTextField();
        adresa = new JTextField();
        cenaZaM2 = new JTextField();
        pokoje = new JTextField();
        vlastnictvi = new JComboBox(Vlastnictvi.values());

        akce = new JButton(typ.name());
        akce.addActionListener(new Smazat());
        add(new JLabel("Nazev:"));
        add(nazev);
        add(new JLabel("Cena:"));
        add(cena);
        add(new JLabel("Plocha:"));
        add(plocha);
        add(new JLabel("Adresa:"));
        add(adresa);
        add(new JLabel("Cena za m2:"));
        add(cenaZaM2);
        add(new JLabel("Pokoje:"));
        add(pokoje);
        add(new JLabel("Vlastnictvi:"));
        add(vlastnictvi);
        add(new JLabel(""));
        add(akce);
        pack();

    }

    class Smazat implements ActionListener {

        public void actionPerformed(ActionEvent e) {
            switch (typ) {
                case NOVY:
                    nemovitost.setAdresa(adresa.getText());
                    nemovitost.setCena(Double.valueOf(cena.getText()));
                    nemovitost.setNazev(nazev.getText());
                    nemovitost.setPlocha(Double.valueOf(plocha.getText()));
                    for (Vlastnictvi v : Vlastnictvi.values()) {
                        if (v.ordinal() == vlastnictvi.getSelectedIndex()) {
                            nemovitost.setVlastnictvi(v);
                            break;
                        }
                    }
                    if (nemovitost instanceof Dum) {
                        Dum d = (Dum) nemovitost;
                        d.setCenaZaM2(Double.valueOf(cenaZaM2.getText()));
                        d.setPocetMistnosti(Integer.valueOf(pokoje.getText()));

                    }
                    if (nemovitost instanceof Byt) {
                        Byt b = (Byt) nemovitost;
                        b.setPocetMistnosti(Integer.valueOf(pokoje.getText()));
                    }
                    if (nemovitost instanceof Pozemek) {
                        Pozemek p = (Pozemek) nemovitost;
                        p.setCenaZaM2(Double.valueOf(cenaZaM2.getText()));
                    }
                    realitka.vloz(nemovitost);
                    break;
                case SMAZAT:
                    realitka.smaz(nemovitost);
                    break;
            }
            table.repaint();
            dispose();

        }
    }
}
